local _E =  require 'ent.obj'	-- All objects inherit this

local ECS = {}
ECS.entities = {}

function ECS.newEnt(model, args)
	local e = _E.inherit(model, args) -- Inherit Master
	ECS.entities[#ECS.entities+1] = e
end

function ECS.update(dt)
	-- Iterate over the entity list(backwards) here and call each's update function:
	for i = #ECS.entities, 1, -1 do
		if ECS.entities[i].isDead then
			table.remove(ECS.entities, i)
		else
			ECS.entities[i]:update(dt) 	-- Notice the synax sugar ':'
										-- All that does is references back to the instance (self)
		end
	end
end

function ECS.draw()
--[[ 
	Inside the 'draw' callback can iterate forwards because we aren't removing objects so we use an ipairs loop...

	for i, v in ipairs(ECS.entities) do
	end

	The first var 'i' is the iteration number(place in table). 
	The second var 'v' is the value of the table entry(reference to the instance)
	
	Since we don't need the iteration count we use underscore to basically say its an un-needed value. Then I
	prefer to use 'e' as a note-to-self that we going over entities
]]

	for _, e in ipairs(ECS.entities) do
		e:draw()
		-- Draw throwing errors, I'll look into it later...
	end


end

return ECS